# coding: utf-8

"""
    Spryngtime Usage Analytics & Billing API

    Spryngtime Usage Analytics & Billing API

    The version of the OpenAPI document: 1.0.0
    Generated by: https://konfigthis.com
"""

from datetime import datetime, date
import typing
from enum import Enum
from typing_extensions import TypedDict, Literal, TYPE_CHECKING


class RequiredMessage(TypedDict):
    role: str

    content: str

class OptionalMessage(TypedDict, total=False):
    pass

class Message(RequiredMessage, OptionalMessage):
    pass
