# coding: utf-8

"""
    Spryngtime Usage Analytics & Billing API

    Spryngtime Usage Analytics & Billing API

    The version of the OpenAPI document: 1.0.0
    Generated by: https://konfigthis.com
"""

from spryngtime_analytics_sdk.paths.root.get import RootGetRaw
from spryngtime_analytics_sdk.paths.users.post import UsersPostRaw


class DefaultApiRaw(
    RootGetRaw,
    UsersPostRaw,
):
    """NOTE:
    This class is auto generated by Konfig (https://konfigthis.com)
    """
    pass
