# coding: utf-8

"""
    Spryngtime Usage Analytics & Billing API

    Spryngtime Usage Analytics & Billing API

    The version of the OpenAPI document: 1.0.0
    Generated by: https://konfigthis.com
"""

from datetime import datetime, date
import typing
from enum import Enum
from typing_extensions import TypedDict, Literal, TYPE_CHECKING


class RequiredUsageDetail(TypedDict):
    prompt_tokens: int

    completion_tokens: int

    total_tokens: int

class OptionalUsageDetail(TypedDict, total=False):
    pass

class UsageDetail(RequiredUsageDetail, OptionalUsageDetail):
    pass
