# coding: utf-8

"""
    Spryngtime Usage Analytics & Billing API

    Spryngtime Usage Analytics & Billing API

    The version of the OpenAPI document: 1.0.0
    Generated by: https://konfigthis.com
"""

from datetime import datetime, date
import typing
from enum import Enum
from typing_extensions import TypedDict, Literal, TYPE_CHECKING

from spryngtime_analytics_sdk.type.open_ai_response import OpenAiResponse
from spryngtime_analytics_sdk.type.usage_detail import UsageDetail

class RequiredTrackUsageRequest(TypedDict):
    key: str

class OptionalTrackUsageRequest(TypedDict, total=False):
    conversationId: str

    openAiResponse: OpenAiResponse

    usage: UsageDetail

class TrackUsageRequest(RequiredTrackUsageRequest, OptionalTrackUsageRequest):
    pass
