# coding: utf-8

"""
    Spryngtime Usage Analytics & Billing API

    Spryngtime Usage Analytics & Billing API

    The version of the OpenAPI document: 1.0.0
    Generated by: https://konfigthis.com
"""

from datetime import datetime, date
import typing
from enum import Enum
from typing_extensions import TypedDict, Literal, TYPE_CHECKING
from pydantic import BaseModel, Field, RootModel


class UsageDetail(BaseModel):
    prompt_tokens: int = Field(alias='prompt_tokens')

    completion_tokens: int = Field(alias='completion_tokens')

    total_tokens: int = Field(alias='total_tokens')
