# coding: utf-8

"""
    Spryngtime Usage Analytics & Billing API

    Spryngtime Usage Analytics & Billing API

    The version of the OpenAPI document: 1.0.0
    Generated by: https://konfigthis.com
"""

from datetime import datetime, date
import typing
from enum import Enum
from typing_extensions import TypedDict, Literal, TYPE_CHECKING
from pydantic import BaseModel, Field, RootModel

from spryngtime_analytics_sdk.pydantic.message import Message

class Choice(BaseModel):
    index: int = Field(alias='index')

    message: Message = Field(alias='message')

    finish_reason: str = Field(alias='finish_reason')

    logprobs: typing.Optional[str] = Field(None, alias='logprobs')
