# coding: utf-8
"""
    Spryngtime Usage Analytics & Billing API

    Spryngtime Usage Analytics & Billing API

    The version of the OpenAPI document: 1.0.0
    Generated by: https://konfigthis.com
"""

import typing
import inspect
from datetime import date, datetime
from spryngtime_analytics_sdk.client_custom import ClientCustom
from spryngtime_analytics_sdk.configuration import Configuration
from spryngtime_analytics_sdk.api_client import ApiClient
from spryngtime_analytics_sdk.type_util import copy_signature
from spryngtime_analytics_sdk.apis.tags.usage_tracking_api import UsageTrackingApi
from spryngtime_analytics_sdk.apis.tags.default_api import DefaultApi



class SpryngtimeAnalyticsSdk(ClientCustom):

    def __init__(self, configuration: typing.Union[Configuration, None] = None, **kwargs):
        super().__init__(configuration, **kwargs)
        if (len(kwargs) > 0):
            configuration = Configuration(**kwargs)
        if (configuration is None):
            raise Exception("configuration is required")
        api_client = ApiClient(configuration)
        self.usage_tracking: UsageTrackingApi = UsageTrackingApi(api_client)
        self.default: DefaultApi = DefaultApi(api_client)
