# coding: utf-8

"""
    Spryngtime Usage Analytics & Billing API

    Spryngtime Usage Analytics & Billing API

    The version of the OpenAPI document: 1.0.0
    Generated by: https://konfigthis.com
"""

from spryngtime_analytics_sdk.paths.root.get import RootGet
from spryngtime_analytics_sdk.paths.users.post import UsersPost
from spryngtime_analytics_sdk.apis.tags.default_api_raw import DefaultApiRaw


class DefaultApi(
    RootGet,
    UsersPost,
):
    """NOTE:
    This class is auto generated by Konfig (https://konfigthis.com)
    """
    raw: DefaultApiRaw

    def __init__(self, api_client=None):
        super().__init__(api_client)
        self.raw = DefaultApiRaw(api_client)
