# coding: utf-8

"""
    Spryngtime Usage Analytics & Billing API

    Spryngtime Usage Analytics & Billing API

    The version of the OpenAPI document: 1.0.0
    Generated by: https://konfigthis.com
"""

from datetime import datetime, date
import typing
from enum import Enum
from typing_extensions import TypedDict, Literal, TYPE_CHECKING

from spryngtime_analytics_sdk.type.message import Message

class RequiredChoice(TypedDict):
    index: int

    message: Message

    finish_reason: str

class OptionalChoice(TypedDict, total=False):
    logprobs: str

class Choice(RequiredChoice, OptionalChoice):
    pass
