# coding: utf-8

"""
    Spryngtime Usage Analytics & Billing API

    Spryngtime Usage Analytics & Billing API

    The version of the OpenAPI document: 1.0.0
    Generated by: https://konfigthis.com
"""

from datetime import datetime, date
import typing
from enum import Enum
from typing_extensions import TypedDict, Literal, TYPE_CHECKING

from spryngtime_analytics_sdk.type.choice import Choice
from spryngtime_analytics_sdk.type.usage_detail import UsageDetail

class RequiredOpenAiResponse(TypedDict):
    id: str

    object: str

    created: int

    model: str

    choices: typing.List[Choice]

    usage: UsageDetail

class OptionalOpenAiResponse(TypedDict, total=False):
    system_fingerprint: str

class OpenAiResponse(RequiredOpenAiResponse, OptionalOpenAiResponse):
    pass
