# coding: utf-8

"""
    Spryngtime Usage Analytics & Billing API

    Spryngtime Usage Analytics & Billing API

    The version of the OpenAPI document: 1.0.0
    Generated by: https://konfigthis.com
"""

from datetime import datetime, date
import typing
from enum import Enum
from typing_extensions import TypedDict, Literal, TYPE_CHECKING
from pydantic import BaseModel, Field, RootModel

from spryngtime_analytics_sdk.pydantic.choice import Choice
from spryngtime_analytics_sdk.pydantic.usage_detail import UsageDetail

class OpenAiResponse(BaseModel):
    id: str = Field(alias='id')

    object: str = Field(alias='object')

    created: int = Field(alias='created')

    model: str = Field(alias='model')

    choices: typing.List[Choice] = Field(alias='choices')

    usage: UsageDetail = Field(alias='usage')

    system_fingerprint: typing.Optional[str] = Field(None, alias='system_fingerprint')
