# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from spryngtime_analytics_sdk.paths.users import Api

from spryngtime_analytics_sdk.paths import PathValues

path = PathValues.USERS